@@ -24,10 +24,13 @@ class Session(object):
         element.set(text)
         return element
 
+    def click_button(self, locator):
+        self.driver.click_button(locator)
+
     def should_have_content(self, content):
         has_content = False
         if self.driver.has_title(content):
             has_content = True
         if self.driver.has_text(content):
             has_content = True
-        return has_content
\ No newline at end of file
+        return has_content
